(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     37485,        792]*)
(*NotebookOutlinePosition[     38363,        820]*)
(*  CellTagsIndexPosition[     38319,        816]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(BeginPackage["\<DisturbingFunction`\>"]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\( \
(*\(\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--Version\)\)\)\)\)\)\)\
\)\)\)\)\)\)\ \(\(\(\(\(\(\(\(\(\(\(\(\(\(\(\(1.2--\)--\)--\)--\)--\)--\)--\)\
--\)--\)--\)--\)--\)--\)--\)--\)--\)\)\(-\)*) \)\(\[IndentingNewLine]\)\( \
(*\(--\(--\(--\(--\(--\(--\(-Carl\)\)\)\)\)\)\)\ Murray, \ QMW, \ London, \ 
      October\ \(\(\(\(\(1999--\)--\)--\)--\)--\) - \(-\(---\)\)*) \)\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \( (*\[IndentingNewLine]Version\ \(history : \[IndentingNewLine]1.0\ \
April\ 1993\[IndentingNewLine]1.1\ March\ 1994\ Improved\ version\ of\ \
ValidArguments\[IndentingNewLine]1.2\ October\ 1999\ Improved\ version\ to\ \
use\ Greek\ letters\)\[IndentingNewLine]*) \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(DisturbingFunction::usage "\<DisturbingFunction.m is a package that \
defines a lot of useful functions for use in the derivation of the planetary \
disturbing function.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(ValidArguments::usage = \*"\"\<ValidArguments[c1,c2,pw] produces an \
ordered list of valid arguments of the expansion of the disturbing function \
up to and including degree 'pw' which start with \
\!\(c\_1\)\[Lambda]'+\!\(c\_2\)\[Lambda].  The components of each argument, {\
\!\(c\_1\),\!\(c\_2\),\!\(c\_3\),\!\(c\_4\),\!\(c\_5\),\!\(c\_6\)}, represent \
the argument \
\!\(c\_1\)\[Lambda]'+\!\(c\_2\)\[Lambda]+\!\(c\_3\)\[CurlyPi]'+\!\(c\_4\)\
\[CurlyPi]+\!\(c\_5\)\[CapitalOmega]'+\!\(c\_6\)\[CapitalOmega].  c1 and c2 \
are integers of the form, e.g. j and i-j, where i, the order of the \
resonance, is an integer.\>\""\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(ValidArgumentsE::usage = \
\*"\"\<ValidArgumentsE[\!\(c\_1\),\!\(c\_2\),pw] produces an ordered list of \
valid arguments of the expansion of the indirect part (external perturber) of \
the disturbing function up to and including degree 'pw' which start with \
\!\(c\_1\)\[Lambda]'+\!\(c\_2\)\[Lambda].  The components of each argument, {\
\!\(c\_1\),\!\(c\_2\),\!\(c\_3\),\!\(c\_4\),\!\(c\_5\),\!\(c\_6\)}, represent \
the argument \
\!\(c\_1\)\[Lambda]'+\!\(c\_2\)\[Lambda]+\!\(c\_3\)\[CurlyPi]'+\!\(c\_4\)\
\[CurlyPi]+\!\(c\_5\)\[CapitalOmega]'+\!\(c\_6\)\[CapitalOmega].  \!\(c\_1\) \
and \!\(c\_2\) are integers of the form, e.g. j and i-j, where i, the order \
of the resonance, is an integer.\>\""\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(ValidArgumentsI::usage = \
\*"\"\<ValidArgumentsI[\!\(c\_1\),\!\(c\_2\),pw] produces an ordered list of \
valid arguments of the expansion of the indirect part(internal perturber) of \
the disturbing function up to and including degree 'pw' which start with \
\!\(c\_1\)\[Lambda]'+\!\(c\_2\)\[Lambda].  The components of each argument, {\
\!\(c\_1\),\!\(c\_2\),\!\(c\_3\),\!\(c\_4\),\!\(c\_5\),\!\(c\_6\)}, represent \
the argument \
\!\(c\_1\)\[Lambda]'+\!\(c\_2\)\[Lambda]+\!\(c\_3\)\[CurlyPi]'+\!\(c\_4\)\
\[CurlyPi]+\!\(c\_5\)\[CapitalOmega]'+\!\(c\_6\)\[CapitalOmega].  \!\(c\_1\) \
and \!\(c\_2\) are integers of the form, e.g. j and i-j, where i, the order \
of the resonance, is an integer.\>\""\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(IndirectTestE::usage = \
\*"\"\<IndirectTestE[{\!\(c\_1\),\!\(c\_2\),\!\(c\_3\),\!\(c\_4\),\!\(c\_5\),\
\!\(c\_6\)}] tests whether or not the argument \
\!\(c\_1\)\[Lambda]'+\!\(c\_2\)\[Lambda]+\!\(c\_3\)\[CurlyPi]'+\!\(c\_4\)\
\[CurlyPi]+\!\(c\_5\)\[CapitalOmega]'+\!\(c\_6\)\[CapitalOmega] is a valid \
argument of the expansion of the indirect part (external perturber) of the \
expansion of the disturbing function.  All the \!\(c\_i\)'s must be explicit \
integers.\>\""\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(IndirectTestI::usage = \
\*"\"\<IndirectTestI[{\!\(c\_1\),\!\(c\_2\),\!\(c\_3\),\!\(c\_4\),\!\(c\_5\),\
\!\(c\_6\)}] tests whether or not the argument \
\!\(c\_1\)\[Lambda]'+\!\(c\_2\)\[Lambda]+\!\(c\_3\)\[CurlyPi]'+\!\(c\_4\)\
\[CurlyPi]+\!\(c\_5\)\[CapitalOmega]'+\!\(c\_6\)\[CapitalOmega] is a valid \
argument of the expansion of the indirect part (internal perturber) of the \
expansion of the disturbing function.  All the \!\(c\_i\)'s must be explicit \
integers.\>\""\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(FlmpAllan::usage = "\<FlmpAllan[l,m,p,inc,pw] gives the series \
expansion of Allan's F(l,m,p) inclination function up to and including powers \
of pw in inc.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(FlmpKaula::usage = "\<FlmpKaula[l,m,p,inc,pw] gives the series \
expansion of Kaula's F(l,m,p) inclination function up to and including powers \
of pw in inc.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Newcomb::usage = "\<Newcomb[a,b,c,d] returns the Newcomb operator, \
usually denoted by X(a,b,c,d) which is a coefficient in the Hansen series \
expansion in the eccentricity.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Hansen::usage = "\<Hansen[a,b,c,ecc,pw] gives the series for the Hansen \
coefficient X(a,b,c) eccentricity function up to powers of pw in ecc.  The \
coefficient of each term in the series is the Newcomb operator, \
X(a,b,c,d).\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(LaplaceSeries::usage = "\<LaplaceSeries[s,j,a,n,pw] gives the nth \
derivative of the Laplace coefficient b(s,j)(a) as a series in a up to and \
including terms of order pw.  s is a half-integer (e.g. 1/2, 3/2); j, n and \
pw are integers.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(LaplaceCoefficient::usage = "\<LaplaceCoefficient[s,j,a,n] gives the \
nth derivative of the Laplace coefficient b(s,j)(a) as a numerical value. s \
is a half-integer (e.g. 1/2, 3/2); j, n are integers.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(SMultiply::usage = "\<SMultiply[s1,s2,max] multiplies s1 by s2 \
truncating powers of e, e', s, s' to order max.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(EllisKaulaD::usage = "\<EllisKaulaD[argument,pmax] finds the main \
coefficient of the direct part of the disturbing function which contains the \
cosine of argument explicitly.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(EllisKaulaE::usage = "\<EllisKaulaE[argument,pmax] finds the main \
coefficient of the indirect part of the disturbing function (for an external \
perturber) which contains the cosine of argument explicitly.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(EllisKaulaI::usage = "\<EllisKaulaI[argument,pmax] finds the main \
coefficient of the indirect part of the disturbing function (for an internal \
perturber) which contains the cosine of argument explicitly.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(DirectPart::usage = "\<DirectPart[argument,pmax] finds the main \
coefficient of the direct part of the disturbing function which contains the \
cosine of argument, or its negative.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(IndirectPartE::usage = "\<IndirectPartE[argument,pmax] finds the main \
coefficient of the indirect part of the disturbing function which contains \
the cosine of argument, or its negative, for an external perturber.\>"\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(IndirectPartI::usage = "\<IndirectPartI[argument,pmax] finds the main \
coefficient of the indirect part of the disturbing function which contains \
the cosine of argument, or its negative, for an internal perturber.\>"\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(DisturbingFunctionE::usage = "\<DisturbingFunctionE[argument,pmax] \
finds the full coefficient of the disturbing function (direct and indirect \
parts) which contains the cosine of argument for an external \
perturber.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(DisturbingFunctionI::usage = "\<DisturbingFunctionI[argument,pmax] \
finds the full coefficient of the disturbing function (direct and indirect \
parts) which contains the cosine of argument for an internal \
perturber.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(BigRE::usage = \*"\"\<BigRE[\!\(c\_1\),\!\(c\_2\),pw] finds the \
expansion of the disturbing function for an external perturber when the basic \
form of the argument is \!\(c\_1\)\[Lambda]'+\!\(c\_2\)\[Lambda]+ ... .  The \
result will include the secular terms (i.e. those independent of lamda' and \
lamda), and those resonant terms associated with \
\!\(c\_1\)\[Lambda]'+\!\(c\_2\)\[Lambda] + ... and integer multiples of the \
argument up to and including terms which are of degree \[LessEqual] pw in the \
eccentricities and inclinations.\>\""\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(NBigRE::usage = \*"\"\<NBigRE[\!\(c\_1\),\!\(c\_2\),pw,\[Alpha]] finds \
the expansion of the disturbing\n\tfunction for an external perturber when \
the basic form of the\n\targument is \
\!\(c\_1\)\[Lambda]'+\!\(c\_2\)\[Lambda]+ ... and calculates the numerical\n\t\
values of the Laplace coefficients taking a/a' = \[Alpha].\>\""\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(BigRI::usage = \*"\"\<BigRI[\!\(c\_1\),\!\(c\_2\),pw] finds the \
expansion of the disturbing function for an internal perturber when the basic \
form of the argument is \!\(c\_1\)\[Lambda]'+\!\(c\_2\)\[Lambda]+ ... .  The \
result will include the secular terms (i.e. those independent of lamda' and \
lamda), and those resonant terms associated with \
\!\(c\_1\)\[Lambda]'+\!\(c\_2\)\[Lambda]+ ... and integer multiples of the \
argument up to and including terms which are of degree \[LessEqual] pw in the \
eccentricities and inclinations.\>\""\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(NBigRI::usage = \*"\"\<NBigRI[\!\(c\_1\),\!\(c\_2\),pw,\[Alpha]] finds \
the expansion of the disturbing\n\tfunction for an internal perturber when \
the basic form of the\n\targument is \
\!\(c\_1\)\[Lambda]'+\!\(c\_2\)\[Lambda]+ ... and calculates the numerical\n\t\
values of the Laplace coefficients taking a/a' = \[Alpha].\>\""\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Global`b /: Global`b[sss_, jjj_, nd_] := 
        Global`b[sss, \(-jjj\), nd] /; jjj < 0;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Begin["\<`Private`\>"]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(ValidArguments[c1_, c2_, n_Integer] := 
      Module[{absarglist, arglist, degree, temparg, order = Abs[c1 + c2], 
          ac1 = c1, ac2 = c2, ii, jj, kk, ll, var}, 
        arglist = 
          Flatten[Table[{kk, ll, ii, jj}, {ii, 
                If[order \[Equal] 0, 0, \(-n\)], n}, {jj, 
                If[order \[Equal] 0 && ii \[Equal] 0, 0, \(-n\) + Abs[ii]], 
                n - Abs[ii]}, {kk, 
                If[order \[Equal] 0 && ii \[Equal] 0 && jj \[Equal] 0, 
                  0, \(-n\) + Abs[ii] + Abs[jj]], 
                n - Abs[ii] - Abs[jj]}, {ll, 
                If[order \[Equal] 0 && ii \[Equal] 0 && jj \[Equal] 0 && 
                    kk \[Equal] 0, 0, \(-n\) + Abs[ii] + Abs[jj] + Abs[kk]], 
                n - Abs[ii] - Abs[jj] - Abs[kk]}], 
            3]; \[IndentingNewLine]arglist = 
          Select[arglist, \((order + Apply[Plus, #] \[Equal] 
                  0)\) &]; \[IndentingNewLine]arglist = 
          Select[arglist, 
            EvenQ[Abs[#[\([1]\)] + #[\([2]\)]]] &]; \
\[IndentingNewLine]absarglist = 
          Map[Abs, arglist]; \[IndentingNewLine]temparg = 
          arglist /. {x1_, x2_, x3_, x4_} \[RuleDelayed] {x3, x4, x1, 
                x2}; \[IndentingNewLine]degree = 
          Apply[Plus, absarglist, 1]; \[IndentingNewLine]arglist = 
          Prepend[Transpose[arglist], temparg]; \[IndentingNewLine]arglist = 
          Prepend[arglist, absarglist]; \[IndentingNewLine]arglist = 
          Sort[Transpose[Prepend[arglist, degree]]]; \[IndentingNewLine]var = 
          Variables[{c1, c2}]; \[IndentingNewLine]If[var =!= {}, 
          If[Coefficient[c1, var[\([1]\)], 1] \[Equal] \(-1\), 
            ac1 = \(-c1\); \ ac2 = \(-c2\)], 
          If[c1 < 0, ac1 = \(-c1\); \ ac2 = \(-c2\)]]; \[IndentingNewLine]If[
          Length[arglist] =!= 0, 
          Transpose[
              Drop[Transpose[arglist], 3]] /. {x1_, x2_, x3_, 
                x4_} \[RuleDelayed] {ac1, ac2, x3, x4, x1, x2}, 
          arglist]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(IndirectTestE[{clamdap_, clamda_, clpp_Integer, clp_Integer, 
          clanp_Integer, clan_Integer}] := 
      Module[{qp = \(-clpp\), q = clp, m1pp = clanp, pq1p = clamdap - 1, 
          pq1 = \(-clamda\) - 1, p, pp, m}, 
        pp = \(-\((pq1p - qp)\)\)/
            2; \[IndentingNewLine]p = \(-\((pq1 - q)\)\)/
            2; \[IndentingNewLine]m = m1pp - 2*pp + 1; \[IndentingNewLine]If[
          p \[LessEqual] 1 && p \[GreaterEqual] 0 && pp \[LessEqual] 1 && 
            pp \[GreaterEqual] 0 && m \[LessEqual] 1 && m \[GreaterEqual] 0 && 
            clamdap =!= 0 && IntegerQ[p] \[Equal] True && 
            IntegerQ[pp] \[Equal] True, True, False]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(ValidArgumentsE[c1_, c2_, pmax_Integer] := 
      Module[{valist, valen, arglist = {}, temp, inonzero, argument1, 
          argument2, var, novar}, 
        var = Variables[{c1, c2}]; \[IndentingNewLine]novar = 
          If[var \[Equal] {}, True, False]; \[IndentingNewLine]valist = 
          ValidArguments[c1, c2, pmax]; \[IndentingNewLine]valen = 
          Length[valist]; \[IndentingNewLine]Do[
          temp = {}; \[IndentingNewLine]If[i \[Equal] 0 || novar, 
            inonzero = False, 
            inonzero = True]; \[IndentingNewLine]argument1 = 
            valist[\([k]\)]; \[IndentingNewLine]If[\(! novar\), 
            argument1 = argument1 /. var[\([1]\)] \[Rule] i]; \ 
          If[inonzero, 
            argument2 = \(-valist[\([k]\)]\)]; \[IndentingNewLine]If[\(! \
novar\), argument2 = 
              argument2 /. 
                var[\([1]\)] \[Rule] \(-i\)]; \[IndentingNewLine]If[
            IndirectTestE[argument1] || IndirectTestE[\(-argument1\)], 
            AppendTo[temp, argument1]]; \[IndentingNewLine]If[inonzero, 
            If[IndirectTestE[argument2] || IndirectTestE[\(-argument2\)], 
              AppendTo[temp, argument2]]]; \[IndentingNewLine]temp = 
            Union[temp]; \[IndentingNewLine]arglist = 
            Join[arglist, temp], {k, 1, valen}, {i, 1, 
            Floor[\((pmax + Abs[c1 + c2])\)/2] + 1}]; \[IndentingNewLine]If[
          novar, Union[arglist], arglist]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(IndirectTestI[{clamdap_, clamda_, clpp_Integer, clp_Integer, 
          clanp_Integer, clan_Integer}] := 
      Module[{qp = \(-clpp\), q = clp, m1pp = clanp, pq1p = clamdap - 1, 
          pq1 = \(-clamda\) - 1, p, pp, m}, 
        pp = \(-\((pq1p - qp)\)\)/
            2; \[IndentingNewLine]p = \(-\((pq1 - q)\)\)/
            2; \[IndentingNewLine]m = m1pp - 2*pp + 1; \[IndentingNewLine]If[
          p \[LessEqual] 1 && p \[GreaterEqual] 0 && pp \[LessEqual] 1 && 
            pp \[GreaterEqual] 0 && m \[LessEqual] 1 && m \[GreaterEqual] 0 && 
            clamda =!= 0 && IntegerQ[p] \[Equal] True && 
            IntegerQ[pp] \[Equal] True, True, False]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(ValidArgumentsI[c1_, c2_, pmax_Integer] := 
      Module[{valist, valen, arglist = {}, temp, inonzero, argument1, 
          argument2, var, novar}, 
        var = Variables[{c1, c2}]; \[IndentingNewLine]novar = 
          If[var \[Equal] {}, True, False]; \[IndentingNewLine]valist = 
          ValidArguments[c1, c2, pmax]; \[IndentingNewLine]valen = 
          Length[valist]; \[IndentingNewLine]Do[
          temp = {}; \[IndentingNewLine]If[i \[Equal] 0 || novar, 
            inonzero = False, 
            inonzero = True]; \[IndentingNewLine]argument1 = 
            valist[\([k]\)]; \[IndentingNewLine]If[\(! novar\), 
            argument1 = argument1 /. var[\([1]\)] \[Rule] i]; \ 
          If[inonzero, 
            argument2 = \(-valist[\([k]\)]\)]; \[IndentingNewLine]If[\(! \
novar\), argument2 = 
              argument2 /. 
                var[\([1]\)] \[Rule] \(-i\)]; \[IndentingNewLine]If[
            IndirectTestI[argument1] || IndirectTestI[\(-argument1\)], 
            AppendTo[temp, argument1]]; \[IndentingNewLine]If[inonzero, 
            If[IndirectTestI[argument2] || IndirectTestI[\(-argument2\)], 
              AppendTo[temp, argument2]]]; \[IndentingNewLine]temp = 
            Union[temp]; \[IndentingNewLine]arglist = 
            Join[arglist, temp], {k, 1, valen}, {i, 0, 
            Floor[\((pmax + Abs[c1 + c2])\)/2] + 1}]; \[IndentingNewLine]If[
          novar, Union[arglist], arglist]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(FlmpAllan[l_Integer, m_Integer, p_Integer, inc_, pw_Integer] := 
      Expand[Normal[
          Series[Expand[\((I^\((l - m)\)*\(\((l + m)\)!\))\)/\((2^
                        l*\(p!\)*\(\((l - p)\)!\))\)*
                Sum[\((\(-1\))\)^k*Binomial[2*\((l - p)\), k]*
                    Binomial[2*p, l - m - k]*inc^\((m - l + 2*p + 2*k)\)*
                    Normal[Series[\((1 - 
                              inc^2)\)^\((\((3*l - m - 2*p - 2*k)\)/
                              2)\), {inc, 0, pw}]], {k, Max[0, l - m - 2*p], 
                    Min[l - m, 2*l - 2*p]}]], {inc, 0, pw}]]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FlmpKaula[l_Integer, m_Integer, p_Integer, inc_, pw_Integer] := 
        Expand[I^\((l - m)\)*FlmpAllan[l, m, p, inc, pw]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Newcomb[a_, b_, c_, d_] := Newcomb[a, \(-b\), d, c] /; d > c\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(Newcomb[a_, b_, c_, d_] := 0 /; c < 0 || d < 0\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Newcomb[a_, b_, c_, 
        d_] := \((2*\((2*b - a)\)*Newcomb[a, b + 1, c - 1, 0] + \((b - a)\)*
                Newcomb[a, b + 2, c - 2, 0])\)/\((4*c)\) /; 
        c > 1 && d \[Equal] 0\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Newcomb[a_, b_, c_, d_] := 
      Block[{j}, \((\(-\((2*\((2*b + a)\)*
                      Newcomb[a, b - 1, c, d - 1])\)\) - \((b + a)\)*
                  Newcomb[a, b - 2, c, d - 2] - \((c - 5*d + 4 + 4*b + a)\)*
                  Newcomb[a, b, c - 1, d - 1] + 
                2*\((c - d + b)\)*
                  Sum[\((\(-1\))\)^j*Binomial[3/2, j]*
                      Newcomb[a, b, c - j, d - j], {j, 2, d}])\)/\((4*d)\) /; 
          c \[GreaterEqual] d && d \[GreaterEqual] 2]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Newcomb[a_, b_, c_, 
        d_] := \((\(-\((2*\((2*b + a)\)*
                    Newcomb[a, b - 1, c, d - 1])\)\) - \((b + a)\)*
                Newcomb[a, b - 2, c, d - 2] - \((c - 5*d + 4 + 4*b + a)\)*
                Newcomb[a, b, c - 1, d - 1])\)/\((4*d)\) /; 
        c \[GreaterEqual] d && d < 2 && d \[NotEqual] 0\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Newcomb[a_, b_, 0, 0] := 1\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Newcomb[a_, b_, 1, 0] := b - a/2\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Hansen[a_, b_, c_, e_, pw_Integer] := 
      Expand[e^Abs[c - b]*
          Sum[Newcomb[a, b, sigma + Max[0, c - b], sigma + Max[0, b - c]]*
              e^\((2*sigma)\), {sigma, 0, 
              Quotient[pw - Abs[c - b], 2]}]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(LaplaceSeries[s_, j_Integer, alpha_, n_Integer, nord_Integer] := 
      LaplaceSeries[s, \(-j\), alpha, n, nord] /; j < 0\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LaplaceSeries[s_, j_Integer, alpha_, 0, nord_Integer] := 
        Block[{ifact}, 
          If[j \[Equal] 0, ifact = 2, 
            ifact = \((2/\(j!\))\)*Product[\((s + ii)\), {ii, 0, j - 1}]*
                alpha^j]; \[IndentingNewLine]Expand[
            ifact*\((1 + 
                  Sum[Product[\((s + jj - 
                              1)\) \((s + j + jj - 
                                1)\)/\((jj*\((j + jj)\))\), {jj, 1, ii}]*
                      alpha^\((2*ii)\), {ii, 
                      1, \((nord - j)\)/2}])\)]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(LaplaceSeries[s_, j_Integer, alpha_, n_Integer, nord_Integer] := 
      D[LaplaceSeries[s, j, alpha, 0, nord + n], {alpha, n}] /; 
        n > 0\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(LaplaceCoefficient[s_, jj_Integer, a_, n_Integer] := 
      Module[{outside, j = Abs[jj], cterm, cbterm, csum, i, k}, 
        outside = 
          2*Product[s + k, {k, 0, j - 1}]/\(j!\)*
            a^\((j - n)\); \[IndentingNewLine]cterm = 
          1; \[IndentingNewLine]cbterm = 
          cterm*Product[j - k, {k, 0, n - 1}]; \[IndentingNewLine]For[
          i = 1; \ csum = 
            cbterm, \((cbterm > $MachineEpsilon)\) || \((cbterm \[Equal] 
                0)\), \(i++\), 
          cterm = cterm*\((s + i - 1)\)*\(\((s + j + i - 1)\)/i\)/\((j + i)\)*
              a^2; \[IndentingNewLine]cbterm = 
            cterm*Product[
                j + 2*i - k, {k, 0, n - 1}]; \[IndentingNewLine]csum = 
            csum + cbterm]; \[IndentingNewLine]Expand[
          outside*csum]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(SMultiply[s1_, s2_, max_Integer] := 
      Module[{ts1, ts2, t}, 
        ts1 = s1 /. {Global`e \[Rule] t*Global`e, 
              Global`e' \[Rule] t*Global`e', Global`s \[Rule] t*Global`s, 
              Global`s' \[Rule] t*Global`s'}; \[IndentingNewLine]ts2 = 
          s2 /. {Global`e \[Rule] t*Global`e, Global`e' \[Rule] t*Global`e', 
              Global`s \[Rule] t*Global`s, 
              Global`s' \[Rule] t*Global`s'}; \[IndentingNewLine]Normal[
            Series[ts1*ts2, {t, 0, max}]] /. t \[Rule] 1]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(EllisKaulaD[{clamdap_, clamda_, clpp_Integer, clp_Integer, 
            clanp_Integer, clan_Integer}, pmax_Integer] := 
        Module[{qp = \(-clpp\), q = clp, msnpp = clanp, msnp = \(-clan\), 
            isum = 0, lmax = pmax - Abs[clan] - Abs[clanp], coeff1, coeff2, 
            coeff3, ifact, xe, xep, ifun, efun, iefun, imin, imax, nmax, 
            mmin, p, pp, fsi, fsip, lapfun, term, i, ss, n, m, abar, jj}, 
          absqqp = Abs[q] + Abs[qp]; \[IndentingNewLine]If[EvenQ[msnpp], 
            mmseven = True, 
            mmseven = False]; \[IndentingNewLine]ppmp = \((msnpp - msnp)\)/
              2; \[IndentingNewLine]If[ppmp < 0, pmin = \(-ppmp\); \ 
            ppmin = 0, pmin = 0; \ 
            ppmin = ppmp]; \[IndentingNewLine]sm2nmin = 
            Max[pmin, 
              ppmin, \(-msnp\) + 2*pmin, \(-msnpp\) + 
                2*ppmin]; \[IndentingNewLine]ssmin = sm2nmin; \ 
          imin = 0; \[IndentingNewLine]imax = 
            Floor[\((pmax - Abs[q] - Abs[qp])\)/2]; \[IndentingNewLine]Do[
            ifact = \((\(\((2  i)\)!\)/\(i!\))\)*\((\((\((\(-1\))\)^
                        i)\)/\((2^\((2  i + 1)\))\))\)*\((Global`\[Alpha])\)^
                  i; \[IndentingNewLine]xe = 
              Hansen[i + kk, \(-clamda\) - q, \(-clamda\), Global`e, 
                pmax - Abs[qp] - Abs[clan] - 
                  Abs[clanp]]; \[IndentingNewLine]xep = 
              Hansen[\(-\((i + kk + 1)\)\), clamdap - qp, clamdap, Global`e', 
                pmax - Abs[q] - Abs[clan] - 
                  Abs[clanp]]; \[IndentingNewLine]efun = 
              SMultiply[xe, xep, pmax]; \[IndentingNewLine]Do[
              nmax = Floor[\((ss - ssmin)\)/2]; \[IndentingNewLine]Do[
                If[\((EvenQ[ss] && 
                        mmseven)\) || \((OddQ[ss] && \(! mmseven\))\), 
                  mmin = 0, mmin = 1]; \[IndentingNewLine]s2mn = 
                  ss - 2*n; \[IndentingNewLine]Do[
                  pp = \((msnpp - m + s2mn)\)/
                      2; \[IndentingNewLine]p = \((msnp - m + s2mn)\)/
                      2; \[IndentingNewLine]If[
                    p \[LessEqual] s2mn && p \[GreaterEqual] pmin && 
                      pp \[LessEqual] s2mn && pp \[GreaterEqual] ppmin, 
                    If[m \[Equal] 0, kappa = 1, 
                      kappa = 2]; \[IndentingNewLine]fsi = 
                      FlmpKaula[s2mn, m, p, Global`s, 
                        pmax - absqqp - 
                          Abs[clanp]]; \[IndentingNewLine]fsip = 
                      FlmpKaula[s2mn, m, pp, Global`s', 
                        pmax - absqqp - Abs[clan]]; \[IndentingNewLine]ifun = 
                      SMultiply[fsi, fsip, 
                        pmax - absqqp]; \[IndentingNewLine]iefun = 
                      SMultiply[efun, ifun, 
                        pmax]; \[IndentingNewLine]coeff1 = \((\((2*ss - 4*n + 
                                1)\)*\(\((ss - n)\)!\))\)/\((2^\((2*
                                  n)\)*\(n!\)*\(\((2*ss - 2*n + 
                                  1)\)!\))\); \[IndentingNewLine]coeff2 = 
                      kappa*\(\((s2mn - m)\)!\)/\(\((s2mn + 
                                m)\)!\); \[IndentingNewLine]Do[
                      jj = clamda + i - 2*abar - 2*n - 2*p + 
                          q; \[IndentingNewLine]vjj = 
                        Variables[jj]; \[IndentingNewLine]If[vjj =!= {}, 
                        If[Coefficient[jj, vjj[\([1]\)], 1] \[Equal] \(-1\), 
                          jj = \(-jj\)], 
                        jj = Abs[
                            jj]]; \[IndentingNewLine]coeff3 = \((\((\(-1\))\)^
                                ss*2^\((2*ss)\))\)/\((\(\((i - ss - 
                                    abar)\)!\)*\(abar!\))\); \
\[IndentingNewLine]lapfun = 
                        Sum[\((\((\(-1\))\)^l/\((\(l!\))\))\)*
                            Binomial[l, k]*\((\(-1\))\)^
                              k*\((Global`\[Alpha])\)^l*
                            Global`b[i + 1/2, jj, 
                              l]*\((iefun /. kk \[Rule] k)\), {l, 0, 
                            lmax}, {k, 0, l}]; \[IndentingNewLine]term = 
                        ifact*coeff1*coeff2*coeff3*
                          lapfun; \[IndentingNewLine]isum = 
                        isum + term, {abar, 0, i - ss}]], {m, mmin, 
                    ss - 2  n, 2}], {n, 0, nmax}], {ss, ssmin, i}], {i, imin, 
              imax}]; \[IndentingNewLine]Expand[isum]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(EllisKaulaE[{clamdap_, clamda_, clpp_Integer, clp_Integer, 
          clanp_Integer, clan_Integer}, pmax_Integer] := 
      Module[{qp = \(-clpp\), q = clp, m1pp = clanp, m1p = \(-clan\), 
          pq1p = clamdap - 1, pq1 = \(-clamda\) - 1, coeff, p, pp, m, kappa, 
          fsi, fsip, xe, xep, efun, ifun, iefun}, 
        pp = \(-\((pq1p - qp)\)\)/
            2; \[IndentingNewLine]p = \(-\((pq1 - q)\)\)/
            2; \[IndentingNewLine]m = m1pp - 2*pp + 1; \[IndentingNewLine]If[
          p \[LessEqual] 1 && p \[GreaterEqual] 0 && pp \[LessEqual] 1 && 
            pp \[GreaterEqual] 0 && m \[LessEqual] 1 && m \[GreaterEqual] 0 && 
            IntegerQ[p] \[Equal] True && IntegerQ[pp] \[Equal] True, 
          absqqp = Abs[q] + Abs[qp]; \[IndentingNewLine]If[m \[Equal] 0, 
            kappa = 1, kappa = 2]; \[IndentingNewLine]coeff = 
            kappa*\(\((1 - m)\)!\)/\(\((1 + m)\)!\); \[IndentingNewLine]fsi = 
            FlmpKaula[1, m, p, Global`s, 
              pmax - absqqp - Abs[clanp]]; \[IndentingNewLine]fsip = 
            FlmpKaula[1, m, pp, Global`s', 
              pmax - absqqp - Abs[clan]]; \[IndentingNewLine]ifun = 
            SMultiply[fsi, fsip, pmax - absqqp]; \[IndentingNewLine]xe = 
            Hansen[1, \(-clamda\) - q, \(-clamda\), Global`e, 
              pmax - Abs[qp] - Abs[clan] - 
                Abs[clanp]]; \[IndentingNewLine]xep = 
            Hansen[\(-2\), clamdap - qp, clamdap, Global`e', 
              pmax - Abs[q] - Abs[clan] - 
                Abs[clanp]]; \[IndentingNewLine]efun = 
            SMultiply[xe, xep, pmax]; \[IndentingNewLine]iefun = 
            SMultiply[efun, ifun, pmax]; \[IndentingNewLine]Expand[
            coeff*iefun], 0]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(EllisKaulaI[{clamdap_, clamda_, clpp_Integer, clp_Integer, 
          clanp_Integer, clan_Integer}, pmax_Integer] := 
      Module[{qp = \(-clpp\), q = clp, m1pp = clanp, m1p = \(-clan\), 
          pq1p = clamdap - 1, pq1 = \(-clamda\) - 1, coeff, p, pp, m, kappa, 
          fsi, fsip, xe, xep, efun, ifun, iefun}, 
        pp = \(-\((pq1p - qp)\)\)/
            2; \[IndentingNewLine]p = \(-\((pq1 - q)\)\)/
            2; \[IndentingNewLine]m = m1pp - 2*pp + 1; \[IndentingNewLine]If[
          p \[LessEqual] 1 && p \[GreaterEqual] 0 && pp \[LessEqual] 1 && 
            pp \[GreaterEqual] 0 && m \[LessEqual] 1 && m \[GreaterEqual] 0 && 
            IntegerQ[p] \[Equal] True && IntegerQ[pp] \[Equal] True, 
          absqqp = 
            Abs[q] + Abs[qp]; \[IndentingNewLine] (*\(m = m1pp - 2*pp + 1;\)*) 
            If[m \[Equal] 0, kappa = 1, 
            kappa = 2]; \[IndentingNewLine]coeff = 
            kappa*\(\((1 - m)\)!\)/\(\((1 + m)\)!\); \[IndentingNewLine]fsi = 
            FlmpKaula[1, m, p, Global`s, 
              pmax - absqqp - Abs[clanp]]; \[IndentingNewLine]fsip = 
            FlmpKaula[1, m, pp, Global`s', 
              pmax - absqqp - Abs[clan]]; \[IndentingNewLine]ifun = 
            SMultiply[fsi, fsip, pmax - absqqp]; \[IndentingNewLine]xe = 
            Hansen[\(-2\), \(-clamda\) - q, \(-clamda\), Global`e, 
              pmax - Abs[qp] - Abs[clan] - 
                Abs[clanp]]; \[IndentingNewLine]xep = 
            Hansen[1, clamdap - qp, clamdap, Global`e', 
              pmax - Abs[q] - Abs[clan] - 
                Abs[clanp]]; \[IndentingNewLine]efun = 
            SMultiply[xe, xep, pmax]; \[IndentingNewLine]iefun = 
            SMultiply[efun, ifun, pmax]; \[IndentingNewLine]Expand[
            coeff*iefun], 0]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DirectPart[argument_List, pmax_Integer] := 
        If[Drop[argument, 2] =!= {0, 0, 0, 0}, 
          EllisKaulaD[argument, pmax] + EllisKaulaD[\(-argument\), pmax], 
          If[Variables[argument] =!= {}, 
            Expand[\((EllisKaulaD[argument, pmax] + 
                    EllisKaulaD[\(-argument\), pmax])\)/2], 
            EllisKaulaD[argument, pmax]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IndirectPartE[argument_List, 
          pmax_Integer] := \(-EllisKaulaE[argument, pmax]\) - 
          EllisKaulaE[\(-argument\), pmax];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IndirectPartI[argument_List, 
          pmax_Integer] := \(-EllisKaulaI[argument, pmax]\) - 
          EllisKaulaI[\(-argument\), pmax];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DisturbingFunctionE[argument_List, 
          pmax_Integer] := \((Global`\[ScriptCapitalG]*
              Global`m'/Global`a')\)*\((DirectPart[argument, pmax]*
                Cos[argument[\([1]\)]*Global`\[Lambda]' + 
                    argument[\([2]\)]*Global`\[Lambda] + 
                    argument[\([3]\)]*Global`\[CurlyPi]' + 
                    argument[\([4]\)]*Global`\[CurlyPi] + 
                    argument[\([5]\)]*Global`\[CapitalOmega]' + 
                    argument[\([6]\)]*Global`\[CapitalOmega]] + 
              Global`\[Alpha]*IndirectPartE[argument, pmax]*
                Cos[argument[\([1]\)]*Global`\[Lambda]' + 
                    argument[\([2]\)]*Global`\[Lambda] + 
                    argument[\([3]\)]*Global`\[CurlyPi]' + 
                    argument[\([4]\)]*Global`\[CurlyPi] + 
                    argument[\([5]\)]*Global`\[CapitalOmega]' + 
                    argument[\([6]\)]*
                      Global`\[CapitalOmega]])\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DisturbingFunctionI[argument_List, 
          pmax_Integer] := \((Global`\[ScriptCapitalG]*
              Global`m/Global`a')\)*\((DirectPart[argument, pmax]*
                Cos[argument[\([1]\)]*Global`\[Lambda]' + 
                    argument[\([2]\)]*Global`\[Lambda] + 
                    argument[\([3]\)]*Global`\[CurlyPi]' + 
                    argument[\([4]\)]*Global`\[CurlyPi] + 
                    argument[\([5]\)]*Global`\[CapitalOmega]' + 
                    argument[\([6]\)]*Global`\[CapitalOmega]] + \((1/
                    Global`\[Alpha]^2)\)*IndirectPartI[argument, pmax]*
                Cos[argument[\([1]\)]*Global`\[Lambda]' + 
                    argument[\([2]\)]*Global`\[Lambda] + 
                    argument[\([3]\)]*Global`\[CurlyPi]' + 
                    argument[\([4]\)]*Global`\[CurlyPi] + 
                    argument[\([5]\)]*Global`\[CapitalOmega]' + 
                    argument[\([6]\)]*
                      Global`\[CapitalOmega]])\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(BigRE[c1_Integer, c2_Integer, pw_Integer] := 
        Module[{args, resargs, secargs, order = Abs[c1 + c2]}, 
          For[resargs = ValidArguments[c1, c2, pw]; \ i = 1, 
            i*order \[LessEqual] pw, \(i++\), 
            resargs = 
              Union[resargs, 
                ValidArguments[i*c1, i*c2, 
                  pw]]]; \[IndentingNewLine]secargs = 
            ValidArguments[0, 0, pw]; \[IndentingNewLine]args = 
            Union[secargs, resargs]; \[IndentingNewLine]Expand[
            Plus @@ Map[DisturbingFunctionE[#, pw] &, args]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NBigRE[c1_Integer, c2_Integer, pw_Integer, a_] := 
        BigRE[c1, c2, pw] /. {Global`\[Alpha] \[Rule] a, 
            Global`b[s_, j_, n_] \[Rule] 
              LaplaceCoefficient[s, j, a, n]};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(BigRI[c1_Integer, c2_Integer, pw_Integer] := 
        Module[{args, resargs, secargs, order = Abs[c1 + c2]}, 
          For[resargs = ValidArguments[c1, c2, pw]; \ i = 1, 
            i*order \[LessEqual] pw, \(i++\), 
            resargs = 
              Union[resargs, 
                ValidArguments[i*c1, i*c2, 
                  pw]]]; \[IndentingNewLine]secargs = 
            ValidArguments[0, 0, pw]; \[IndentingNewLine]args = 
            Union[secargs, resargs]; \[IndentingNewLine]Expand[
            Plus @@ Map[DisturbingFunctionI[#, pw] &, args]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NBigRI[c1_Integer, c2_Integer, pw_Integer, a_] := 
        BigRI[c1, c2, pw] /. {Global`\[Alpha] \[Rule] a, 
            Global`b[s_, j_, n_] \[Rule] 
              LaplaceCoefficient[s, j, a, n]};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(End[]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Protect[ValidArguments, IndirectTestE, IndirectTestI, ValidArgumentsE, 
      ValidArgumentsI, FlmpKaula, FlmpAllan, Newcomb, Hansen, LaplaceSeries, 
      DisturbingFunctionE, DisturbingFunctionI, SMultiply, DirectPart, 
      LaplaceCoefficient, EllisKaulaD, IndirectPartE, EllisKaulaE, 
      IndirectPartI, EllisKaulaI, BigRE, BigRI, NBigRE, NBigRI]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(EndPackage[]\)], "Input",
  InitializationCell->True]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->Automatic,
WindowSize->{698, 478},
WindowMargins->{{17, Automatic}, {Automatic, 41}},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]X2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000000`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 100, 2, 27, "Input",
  InitializationCell->True],
Cell[1820, 53, 452, 8, 43, "Input",
  InitializationCell->True],
Cell[2275, 63, 324, 5, 107, "Input",
  InitializationCell->True],
Cell[2602, 70, 233, 4, 75, "Input",
  InitializationCell->True],
Cell[2838, 76, 687, 11, 139, "Input",
  InitializationCell->True],
Cell[3528, 89, 765, 12, 139, "Input",
  InitializationCell->True],
Cell[4296, 103, 764, 12, 139, "Input",
  InitializationCell->True],
Cell[5063, 117, 536, 9, 107, "Input",
  InitializationCell->True],
Cell[5602, 128, 536, 9, 107, "Input",
  InitializationCell->True],
Cell[6141, 139, 222, 4, 59, "Input",
  InitializationCell->True],
Cell[6366, 145, 222, 4, 59, "Input",
  InitializationCell->True],
Cell[6591, 151, 239, 4, 75, "Input",
  InitializationCell->True],
Cell[6833, 157, 292, 5, 91, "Input",
  InitializationCell->True],
Cell[7128, 164, 303, 5, 91, "Input",
  InitializationCell->True],
Cell[7434, 171, 266, 4, 75, "Input",
  InitializationCell->True],
Cell[7703, 177, 176, 3, 59, "Input",
  InitializationCell->True],
Cell[7882, 182, 241, 4, 75, "Input",
  InitializationCell->True],
Cell[8126, 188, 271, 4, 75, "Input",
  InitializationCell->True],
Cell[8400, 194, 271, 4, 75, "Input",
  InitializationCell->True],
Cell[8674, 200, 245, 4, 75, "Input",
  InitializationCell->True],
Cell[8922, 206, 282, 5, 75, "Input",
  InitializationCell->True],
Cell[9207, 213, 282, 5, 75, "Input",
  InitializationCell->True],
Cell[9492, 220, 283, 5, 75, "Input",
  InitializationCell->True],
Cell[9778, 227, 283, 5, 75, "Input",
  InitializationCell->True],
Cell[10064, 234, 610, 9, 139, "Input",
  InitializationCell->True],
Cell[10677, 245, 393, 6, 75, "Input",
  InitializationCell->True],
Cell[11073, 253, 609, 9, 139, "Input",
  InitializationCell->True],
Cell[11685, 264, 393, 6, 75, "Input",
  InitializationCell->True],
Cell[12081, 272, 154, 3, 27, "Input",
  InitializationCell->True],
Cell[12238, 277, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[12324, 281, 2051, 37, 363, "Input",
  InitializationCell->True],
Cell[14378, 320, 724, 12, 139, "Input",
  InitializationCell->True],
Cell[15105, 334, 1492, 26, 331, "Input",
  InitializationCell->True],
Cell[16600, 362, 723, 12, 139, "Input",
  InitializationCell->True],
Cell[17326, 376, 1492, 26, 331, "Input",
  InitializationCell->True],
Cell[18821, 404, 655, 11, 139, "Input",
  InitializationCell->True],
Cell[19479, 417, 188, 3, 43, "Input",
  InitializationCell->True],
Cell[19670, 422, 123, 3, 27, "Input",
  InitializationCell->True],
Cell[19796, 427, 107, 2, 27, "Input",
  InitializationCell->True],
Cell[19906, 431, 249, 5, 59, "Input",
  InitializationCell->True],
Cell[20158, 438, 550, 10, 107, "Input",
  InitializationCell->True],
Cell[20711, 450, 382, 7, 59, "Input",
  InitializationCell->True],
Cell[21096, 459, 87, 2, 27, "Input",
  InitializationCell->True],
Cell[21186, 463, 93, 2, 27, "Input",
  InitializationCell->True],
Cell[21282, 467, 290, 6, 91, "Input",
  InitializationCell->True],
Cell[21575, 475, 182, 3, 43, "Input",
  InitializationCell->True],
Cell[21760, 480, 603, 12, 123, "Input",
  InitializationCell->True],
Cell[22366, 494, 205, 4, 43, "Input",
  InitializationCell->True],
Cell[22574, 500, 855, 17, 171, "Input",
  InitializationCell->True],
Cell[23432, 519, 577, 10, 123, "Input",
  InitializationCell->True],
Cell[24012, 531, 4559, 75, 683, "Input",
  InitializationCell->True],
Cell[28574, 608, 1776, 29, 347, "Input",
  InitializationCell->True],
Cell[30353, 639, 1832, 31, 347, "Input",
  InitializationCell->True],
Cell[32188, 672, 430, 8, 107, "Input",
  InitializationCell->True],
Cell[32621, 682, 201, 4, 43, "Input",
  InitializationCell->True],
Cell[32825, 688, 201, 4, 43, "Input",
  InitializationCell->True],
Cell[33029, 694, 1041, 18, 171, "Input",
  InitializationCell->True],
Cell[34073, 714, 1056, 18, 171, "Input",
  InitializationCell->True],
Cell[35132, 734, 627, 12, 123, "Input",
  InitializationCell->True],
Cell[35762, 748, 262, 5, 59, "Input",
  InitializationCell->True],
Cell[36027, 755, 627, 12, 123, "Input",
  InitializationCell->True],
Cell[36657, 769, 262, 5, 59, "Input",
  InitializationCell->True],
Cell[36922, 776, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[36991, 780, 414, 6, 91, "Input",
  InitializationCell->True],
Cell[37408, 788, 73, 2, 27, "Input",
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

